@@ -2,10 +2,10 @@
 
 #
 # DaVinci Resolve Multi Debian package creator
-# Release 2020-12-15
+# Release 2020-12-17
 # By Daniel Tufvesson
 #
-MAKERESOLVEDEB_VERSION=1.4.2
+MAKERESOLVEDEB_VERSION=1.4.3
 
 check_command() {
     echo -n "Checking for ${1}..."
@@ -150,15 +150,6 @@ process15() {
     create_directory ${DEB_DIR}/usr/lib/
     extract_tgz ${UNPACK_DIR}/share/panels/dvpanel-framework-linux-x86_64.tgz ${DEB_DIR}/usr/lib/ libDaVinciPanelAPI.so
 
-    # Create udev rules
-    create_directory ${DEB_DIR}/lib/udev/rules.d
-    cat > ${DEB_DIR}/lib/udev/rules.d/75-davincipanel.rules <<EOF
-SUBSYSTEM=="usb", ATTRS{idVendor}=="1edb", MODE="0666"
-EOF
-    cat > ${DEB_DIR}/lib/udev/rules.d/75-sdx.rules <<EOF
-SUBSYSTEM=="usb", ENV{DEVTYPE}=="usb_device", ATTRS{idVendor}=="096e", MODE="0666"
-EOF
-
     # Create desktop shortcuts
     assert_object ${DEB_DIR}/opt/resolve/graphics/DV_Resolve.png
     cat > ${DEB_DIR}/usr/share/applications/${DEB_NAME}.desktop <<EOF
@@ -252,15 +243,6 @@ process16() {
     # Create common data dir
     create_directory ${DEB_DIR}/var/BlackmagicDesign/DaVinci\ Resolve
 
-    # Create udev rules
-    create_directory ${DEB_DIR}/lib/udev/rules.d
-    cat > ${DEB_DIR}/lib/udev/rules.d/75-davincipanel.rules <<EOF
-SUBSYSTEM=="usb", ATTRS{idVendor}=="1edb", MODE="0666"
-EOF
-    cat > ${DEB_DIR}/lib/udev/rules.d/75-sdx.rules <<EOF
-SUBSYSTEM=="usb", ENV{DEVTYPE}=="usb_device", ATTRS{idVendor}=="096e", MODE="0666"
-EOF
-
     # Create desktop shortcuts
     assert_object ${DEB_DIR}/opt/resolve/graphics/DV_Resolve.png
     cat > ${DEB_DIR}/usr/share/applications/${DEB_NAME}.desktop <<EOF
@@ -354,22 +336,6 @@ process17() {
     # Create common data dir
     create_directory ${DEB_DIR}/var/BlackmagicDesign/DaVinci\ Resolve
 
-    # Create udev rules
-    create_directory ${DEB_DIR}/lib/udev/rules.d
-    cat > ${DEB_DIR}/lib/udev/rules.d/75-davincipanel.rules <<EOF
-SUBSYSTEM=="usb", ATTRS{idVendor}=="1edb", MODE="0666"
-EOF
-    cat > ${DEB_DIR}/lib/udev/rules.d/75-davincikb.rules <<EOF
-SUBSYSTEMS=="usb", ENV{.LOCAL_ifNum}="$attr{bInterfaceNumber}"
-# Editor Keyboard
-SUBSYSTEM=="hidraw", KERNEL=="hidraw*", ATTRS{idVendor}=="1edb", ATTRS{idProduct}=="da0b", ENV{.LOCAL_ifNum}=="04", MODE="0666"
-# Speed Editor Keyboard
-SUBSYSTEM=="hidraw", KERNEL=="hidraw*", ATTRS{idVendor}=="1edb", ATTRS{idProduct}=="da0e", ENV{.LOCAL_ifNum}=="02", MODE="0666"
-EOF
-    cat > ${DEB_DIR}/lib/udev/rules.d/75-sdx.rules <<EOF
-SUBSYSTEM=="usb", ENV{DEVTYPE}=="usb_device", ATTRS{idVendor}=="096e", MODE="0666"
-EOF
-
     # Create desktop shortcuts
     assert_object ${DEB_DIR}/opt/resolve/graphics/DV_Resolve.png
     cat > ${DEB_DIR}/usr/share/applications/${DEB_NAME}.desktop <<EOF
@@ -483,6 +449,29 @@ installer_extract_native() {
     fi
 }
 
+processudev() {
+    # Create udev rules
+    create_directory ${DEB_DIR}/lib/udev/rules.d
+    cat > ${DEB_DIR}/lib/udev/rules.d/75-davincipanel.rules <<EOF
+SUBSYSTEM=="usb", ATTRS{idVendor}=="1edb", MODE="0666"
+EOF
+    cat > ${DEB_DIR}/lib/udev/rules.d/75-davincikb.rules <<EOF
+SUBSYSTEMS=="usb", ENV{.LOCAL_ifNum}="\$attr{bInterfaceNumber}"
+# Editor Keyboard
+SUBSYSTEM=="hidraw", KERNEL=="hidraw*", ATTRS{idVendor}=="1edb", ATTRS{idProduct}=="da0b", ENV{.LOCAL_ifNum}=="04", MODE="0666"
+# Speed Editor Keyboard
+SUBSYSTEM=="hidraw", KERNEL=="hidraw*", ATTRS{idVendor}=="1edb", ATTRS{idProduct}=="da0e", ENV{.LOCAL_ifNum}=="02", MODE="0666"
+EOF
+    cat > ${DEB_DIR}/lib/udev/rules.d/75-sdx.rules <<EOF
+SUBSYSTEM=="usb", ENV{DEVTYPE}=="usb_device", ATTRS{idVendor}=="096e", MODE="0666"
+EOF
+    # Add postinst commands
+    cat >> ${DEB_DIR}/DEBIAN/postinst <<EOF
+udevadm control --reload-rules
+udevadm trigger
+EOF
+}
+
 echo "MakeResolveDeb ${MAKERESOLVEDEB_VERSION}"
 
 # Check argument
@@ -559,18 +548,21 @@ case $RESOLVE_VERSION in
 	echo "Using Resolve 15 conversion process"
 	installer_extract_xorriso
 	process15
+	processudev
 	;;
     16.*)
 	echo "Using Resolve 16 conversion process"
 	installer_extract_native
 	process16
 	process1617braw
+	processudev
 	;;
     17.*)
 	echo "Using Resolve 17 conversion process"
 	installer_extract_native
 	process17
 	process1617braw
+	processudev
 	;;
     *)
 	echo "Unknown Resolve version"
@@ -578,6 +570,7 @@ case $RESOLVE_VERSION in
 	installer_extract_native
 	process17
 	process1617braw
+	processudev
 	;;
 esac
 
